<?php
/**
 * Copyright 2010-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 * http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

namespace Aws\CloudSearch\Enum;

use Aws\Common\Enum;

/**
 * Contains enumerable IndexFieldType values
 */
class IndexFieldType extends Enum
{
    const UINT = 'uint';
    const INT = 'int';
    const DOUBLE = 'double';
    const LITERAL = 'literal';
    const TEXT = 'text';
    const DATE = 'date';
    const LATLON = 'latlon';
    const INT_ARRAY = 'int-array';
    const DOUBLE_ARRAY = 'double-array';
    const LITERAL_ARRAY = 'literal-array';
    const TEXT_ARRAY = 'text-array';
    const DATE_ARRAY = 'date-array';
}
